itkwasm.polydata - itkwasm python documentation
Description: Module Contents: Classes:,, PolyDataType,,, PolyData,,,,, Functions:,,_default_points,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.polydata`

## Module Contents

### Classes

`PolyDataType` |
`PolyData` |

### Functions

`_default_points` |

### API

class itkwasm.polydata.PolyDataType
  pointPixelComponentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  pointPixelType: itkwasm.pixel_types.PixelTypes

    None

  pointPixelComponents: int

    1

  cellPixelComponentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  cellPixelType: itkwasm.pixel_types.PixelTypes

    None

  cellPixelComponents: int

    1

itkwasm.polydata._default_points() → numpy.typing.ArrayLike

class itkwasm.polydata.PolyData
  polyDataType: Union[itkwasm.polydata.PolyDataType, Dict]

    None

  name: str

    ‘PolyData’

  numberOfPoints: int

    0

  points: numpy.typing.ArrayLike

    None

  verticesBufferSize: int

    0

  vertices: Optional[numpy.typing.ArrayLike]

    None

  linesBufferSize: int

    0

  lines: Optional[numpy.typing.ArrayLike]

    None

  polygonsBufferSize: int

    0

  polygons: Optional[numpy.typing.ArrayLike]

    None

  triangleStripsBufferSize: int

    0

  triangleStrips: Optional[numpy.typing.ArrayLike]

    None

  numberOfPointPixels: int

    0

  pointData: Optional[numpy.typing.ArrayLike]

    None

  numberOfCellPixels: int

    0

  cellData: Optional[numpy.typing.ArrayLike]

    None

  __post_init__()